@@ -1,4 +1,4 @@
-/*
+/**
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -14,19 +14,22 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 package org.apache.nutch.crawl;
 
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.conf.Configured;
-import org.apache.hadoop.io.Text;
+import org.apache.nutch.storage.WebPage;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 import java.lang.invoke.MethodHandles;
+import java.util.HashSet;
+import java.util.Set;
 
 /**
  * This class provides common methods for implementations of
- * <code>FetchSchedule</code>.
+ * {@link FetchSchedule}.
  * 
  * @author Andrzej Bialecki
  */
@@ -38,6 +41,14 @@ public abstract class AbstractFetchSchedule extends Configured implements
   protected int defaultInterval;
   protected int maxInterval;
 
+  private static final Set<WebPage.Field> FIELDS = new HashSet<WebPage.Field>();
+
+  static {
+    FIELDS.add(WebPage.Field.FETCH_TIME);
+    FIELDS.add(WebPage.Field.RETRIES_SINCE_FETCH);
+    FIELDS.add(WebPage.Field.FETCH_INTERVAL);
+  }
+
   public AbstractFetchSchedule() {
     super(null);
   }
@@ -53,8 +64,8 @@ public abstract class AbstractFetchSchedule extends Configured implements
       return;
     defaultInterval = conf.getInt("db.fetch.interval.default", 0);
     maxInterval = conf.getInt("db.fetch.interval.max", 0);
-    LOG.info("defaultInterval={}", defaultInterval);
-    LOG.info("maxInterval={}", maxInterval);
+    LOG.info("defaultInterval=" + defaultInterval);
+    LOG.info("maxInterval=" + maxInterval);
   }
 
   /**
@@ -65,16 +76,14 @@ public abstract class AbstractFetchSchedule extends Configured implements
    * 
    * @param url
    *          URL of the page.
-   * 
-   * @param datum
-   *          datum instance to be initialized (modified in place).
+   * @param page
+   *          {@link WebPage} object relative to the URL
    */
   @Override
-  public CrawlDatum initializeSchedule(Text url, CrawlDatum datum) {
-    datum.setFetchTime(System.currentTimeMillis());
-    datum.setFetchInterval(defaultInterval);
-    datum.setRetriesSinceFetch(0);
-    return datum;
+  public void initializeSchedule(String url, WebPage page) {
+    page.setFetchTime(System.currentTimeMillis());
+    page.setFetchInterval(defaultInterval);
+    page.setRetriesSinceFetch(0);
   }
 
   /**
@@ -84,11 +93,9 @@ public abstract class AbstractFetchSchedule extends Configured implements
    * preserve this behavior.
    */
   @Override
-  public CrawlDatum setFetchSchedule(Text url, CrawlDatum datum,
-      long prevFetchTime, long prevModifiedTime, long fetchTime,
-      long modifiedTime, int state) {
-    datum.setRetriesSinceFetch(0);
-    return datum;
+  public void setFetchSchedule(String url, WebPage page, long prevFetchTime,
+      long prevModifiedTime, long fetchTime, long modifiedTime, int state) {
+    page.setRetriesSinceFetch(0);
   }
 
   /**
@@ -97,27 +104,22 @@ public abstract class AbstractFetchSchedule extends Configured implements
    * never exceed <code>maxInterval</code>.
    * 
    * @param url
-   *          URL of the page.
-   * 
-   * @param datum
-   *          datum instance to be adjusted.
-   * 
-   * @return adjusted page information, including all original information.
-   *         NOTE: this may be a different instance than @see CrawlDatum, but
-   *         implementations should make sure that it contains at least all
-   *         information from @see CrawlDatum.
+   *          URL of the page
+   * @param page
+   *          {@link WebPage} object relative to the URL
    */
   @Override
-  public CrawlDatum setPageGoneSchedule(Text url, CrawlDatum datum,
-      long prevFetchTime, long prevModifiedTime, long fetchTime) {
+  public void setPageGoneSchedule(String url, WebPage page, long prevFetchTime,
+      long prevModifiedTime, long fetchTime) {
     // no page is truly GONE ... just increase the interval by 50%
     // and try much later.
-    if ((datum.getFetchInterval() * 1.5f) < maxInterval)
-      datum.setFetchInterval(datum.getFetchInterval() * 1.5f);
-    else
-      datum.setFetchInterval(maxInterval * 0.9f);
-    datum.setFetchTime(fetchTime + (long) datum.getFetchInterval() * 1000);
-    return datum;
+    if ((page.getFetchInterval() * 1.5f) < maxInterval) {
+      int newFetchInterval = (int) (page.getFetchInterval() * 1.5f);
+      page.setFetchInterval(newFetchInterval);
+    } else {
+      page.setFetchInterval((int) (maxInterval * 0.9f));
+    }
+    page.setFetchTime(fetchTime + page.getFetchInterval() * 1000L);
   }
 
   /**
@@ -126,31 +128,21 @@ public abstract class AbstractFetchSchedule extends Configured implements
    * day in the future and increases the retry counter.
    * 
    * @param url
-   *          URL of the page.
-   * 
-   * @param datum
-   *          page information.
-   * 
+   *          URL of the page
+   * @param page
+   *          {@link WebPage} object relative to the URL
    * @param prevFetchTime
-   *          previous fetch time.
-   * 
+   *          previous fetch time
    * @param prevModifiedTime
-   *          previous modified time.
-   * 
+   *          previous modified time
    * @param fetchTime
-   *          current fetch time.
-   * 
-   * @return adjusted page information, including all original information.
-   *         NOTE: this may be a different instance than @see CrawlDatum, but
-   *         implementations should make sure that it contains at least all
-   *         information from @see CrawlDatum.
+   *          current fetch time
    */
   @Override
-  public CrawlDatum setPageRetrySchedule(Text url, CrawlDatum datum,
+  public void setPageRetrySchedule(String url, WebPage page,
       long prevFetchTime, long prevModifiedTime, long fetchTime) {
-    datum.setFetchTime(fetchTime + (long) SECONDS_PER_DAY * 1000);
-    datum.setRetriesSinceFetch(datum.getRetriesSinceFetch() + 1);
-    return datum;
+    page.setFetchTime(fetchTime + SECONDS_PER_DAY * 1000L);
+    page.setRetriesSinceFetch(page.getRetriesSinceFetch() + 1);
   }
 
   /**
@@ -159,12 +151,8 @@ public abstract class AbstractFetchSchedule extends Configured implements
    * @return the date as a long.
    */
   @Override
-  public long calculateLastFetchTime(CrawlDatum datum) {
-    if (datum.getStatus() == CrawlDatum.STATUS_DB_UNFETCHED) {
-      return 0L;
-    } else {
-      return datum.getFetchTime() - (long) datum.getFetchInterval() * 1000;
-    }
+  public long calculateLastFetchTime(WebPage page) {
+    return page.getFetchTime() - page.getFetchInterval() * 1000L;
   }
 
   /**
@@ -172,39 +160,34 @@ public abstract class AbstractFetchSchedule extends Configured implements
    * in the current fetchlist. NOTE: a true return value does not guarantee that
    * the page will be fetched, it just allows it to be included in the further
    * selection process based on scores. The default implementation checks
-   * <code>fetchTime</code>, if it is higher than the <code>curTime</code> it
-   * returns false, and true otherwise. It will also check that fetchTime is not
-   * too remote (more than <code>maxInterval</code>, in which case it lowers the
-   * interval and returns true.
-   * 
+   * <code>fetchTime</code>, if it is higher than the current time
+   * it returns false, and true otherwise. It will also check that
+   * fetchTime is not too remote (more than <code>maxInterval</code>),
+   * in which case it lowers the interval and returns true.
+   *
    * @param url
-   *          URL of the page.
-   * 
-   * @param datum
-   *          datum instance.
-   * 
+   *          URL of the page
+   * @param page
+   *          {@link WebPage} object relative to the URL
    * @param curTime
    *          reference time (usually set to the time when the fetchlist
    *          generation process was started).
-   * 
    * @return true, if the page should be considered for inclusion in the current
    *         fetchlist, otherwise false.
    */
   @Override
-  public boolean shouldFetch(Text url, CrawlDatum datum, long curTime) {
+  public boolean shouldFetch(String url, WebPage page, long curTime) {
     // pages are never truly GONE - we have to check them from time to time.
-    // pages with too long a fetchInterval are adjusted so that they fit within
-    // a maximum fetchInterval (segment retention period).
-    if (datum.getFetchTime() - curTime > (long) maxInterval * 1000) {
-      if (datum.getFetchInterval() > maxInterval) {
-        datum.setFetchInterval(maxInterval * 0.9f);
+    // pages with too long fetchInterval are adjusted so that they fit within
+    // maximum fetchInterval (batch retention period).
+    long fetchTime = page.getFetchTime();
+    if (fetchTime - curTime > maxInterval * 1000L) {
+      if (page.getFetchInterval() > maxInterval) {
+        page.setFetchInterval(Math.round(maxInterval * 0.9f));
       }
-      datum.setFetchTime(curTime);
+      page.setFetchTime(curTime);
     }
-    if (datum.getFetchTime() > curTime) {
-      return false; // not time yet
-    }
-    return true;
+    return fetchTime <= curTime;
   }
 
   /**
@@ -212,28 +195,28 @@ public abstract class AbstractFetchSchedule extends Configured implements
    * retriesSinceFetch and page signature, so that it forces refetching.
    * 
    * @param url
-   *          URL of the page.
-   * 
-   * @param datum
-   *          datum instance.
-   * 
+   *          URL of the page
+   * @param page
+   *          {@link WebPage} object relative to the URL
    * @param asap
    *          if true, force refetch as soon as possible - this sets the
    *          fetchTime to now. If false, force refetch whenever the next fetch
    *          time is set.
    */
   @Override
-  public CrawlDatum forceRefetch(Text url, CrawlDatum datum, boolean asap) {
+  public void forceRefetch(String url, WebPage page, boolean asap) {
     // reduce fetchInterval so that it fits within the max value
-    if (datum.getFetchInterval() > maxInterval)
-      datum.setFetchInterval(maxInterval * 0.9f);
-    datum.setStatus(CrawlDatum.STATUS_DB_UNFETCHED);
-    datum.setRetriesSinceFetch(0);
-    datum.setSignature(null);
-    datum.setModifiedTime(0L);
+    if (page.getFetchInterval() > maxInterval)
+      page.setFetchInterval(Math.round(maxInterval * 0.9f));
+    page.setStatus((int) CrawlStatus.STATUS_UNFETCHED);
+    page.setRetriesSinceFetch(0);
+    // TODO: row.setSignature(null) ??
+    page.setModifiedTime(0L);
     if (asap)
-      datum.setFetchTime(System.currentTimeMillis());
-    return datum;
+      page.setFetchTime(System.currentTimeMillis());
   }
 
+  public Set<WebPage.Field> getFields() {
+    return FIELDS;
+  }
 }
