@@ -1,4 +1,4 @@
-/*
+/**
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -14,6 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 package org.apache.nutch.protocol.ftp;
 
 import java.io.BufferedReader;
@@ -21,23 +22,21 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.OutputStream;
-
+import java.nio.charset.StandardCharsets;
 import java.net.InetAddress;
 import java.net.Socket;
-
 import java.util.List;
+//import java.util.LinkedList;
 
 import org.apache.commons.net.MalformedServerReplyException;
-
 import org.apache.commons.net.ftp.FTP;
 import org.apache.commons.net.ftp.FTPCommand;
 import org.apache.commons.net.ftp.FTPFile;
 import org.apache.commons.net.ftp.FTPFileEntryParser;
 import org.apache.commons.net.ftp.FTPReply;
-
 import org.apache.commons.net.ftp.FTPConnectionClosedException;
 
-/**
+/***********************************************
  * Client.java encapsulates functionalities necessary for nutch to get dir list
  * and retrieve file from an FTP server. This class takes care of all low level
  * details of interacting with an FTP server and provides a convenient higher
@@ -50,12 +49,12 @@ import org.apache.commons.net.ftp.FTPConnectionClosedException;
  * denominator as following: (1) Use stream mode for data transfer. Block mode
  * will be better for multiple file downloading and partial file downloading.
  * However not every ftpd has block mode support. (2) Use passive mode for data
- * connection. So Nutch will work if we run behind firewall. (3) Data connection
+ * connection. So nutch will work if we run behind firewall. (3) Data connection
  * is opened/closed per ftp command for the reasons listed in (1). There are ftp
- * servers out there, when partial downloading is enforced by closing data
+ * servers out there, when partial downloading is enforeced by closing data
  * channel socket on our client side, the server side immediately closes control
  * channel (socket). Our codes deal with such a bad behavior. (4) LIST is used
- * to obtain remote file attributes if possible. MDTM and SIZE would be nice, but
+ * to obtain remote file attributes if possible. MDTM &amp; SIZE would be nice, but
  * not as ubiquitously implemented as LIST. (5) Avoid using ABOR in single
  * thread? Do not use it at all.
  * 
@@ -64,7 +63,7 @@ import org.apache.commons.net.ftp.FTPConnectionClosedException;
  * IOException.
  * 
  * @author John Xing
- */
+ ***********************************************/
 
 public class Client extends FTP {
   private int __dataTimeout;
@@ -75,7 +74,7 @@ public class Client extends FTP {
   // private FTPFileEntryParser __entryParser;
   private String __systemName;
 
-  /** Public default constructor */
+  // constructor
   public Client() {
     __initDefaults();
     __dataTimeout = -1;
@@ -87,10 +86,10 @@ public class Client extends FTP {
     __passiveHost = null;
     __passivePort = -1;
     __systemName = null;
-    // __fileType = FTP.ASCII_FILE_TYPE;
-    // __fileFormat = FTP.NON_PRINT_TEXT_FORMAT;
-    // __entryParser = null;
-  }
+    /*
+     * __fileType = FTP.ASCII_FILE_TYPE; __fileFormat =
+     * FTP.NON_PRINT_TEXT_FORMAT; __entryParser = null;
+     */}
 
   // parse reply for pass()
   private void __parsePassiveModeReply(String reply)
@@ -136,14 +135,13 @@ public class Client extends FTP {
   }
 
   /**
-   * Open a passive data connection socket
+   * open a passive data connection socket
    * 
-   * @param command the FTP command to be sent to the FTP server
-   * @param arg the argument associated with the command
-   * @return a passive {@link Socket} connections
-   * @throws IOException if there is an error entering passive mode
-   * @throws FtpExceptionCanNotHaveDataConnection can occur if there is a
-   * malformed server reply
+   * @param command
+   * @param arg
+   * @return
+   * @throws IOException
+   * @throws FtpExceptionCanNotHaveDataConnection
    */
   protected Socket __openPassiveDataConnection(int command, String arg)
       throws IOException, FtpExceptionCanNotHaveDataConnection {
@@ -214,7 +212,6 @@ public class Client extends FTP {
   /***
    * Sets the timeout in milliseconds to use for data connection. set
    * immediately after opening the data connection.
-   * @param timeout maximum timeout in milliseconds
    ***/
   public void setDataTimeout(int timeout) {
     __dataTimeout = timeout;
@@ -228,7 +225,6 @@ public class Client extends FTP {
    * @exception IOException
    *              If an error occurs while disconnecting.
    ***/
-  @Override
   public void disconnect() throws IOException {
     __initDefaults();
     super.disconnect();
@@ -313,23 +309,16 @@ public class Client extends FTP {
   }
 
   /**
-   * Retrieve list reply for path
+   * Retrieve a list reply for path
    * 
-   * @param path a path on the FTP server
-   * @param entries a initialized {@link List} of 
-   * {@link FTPFile}'s to populate with entries found at the path
-   * @param limit optionally impose a download limit if this value 
-   * is &gt;= 0, otherwise no limit
-   * @param parser a configured {@link FTPFileEntryParser}
-   * @throws IOException if there is a fatal I/O error, could be related to 
-   * opening a passive data connection or retrieving data from the specified path
-   * @throws FtpExceptionCanNotHaveDataConnection if an error occurs whilst 
-   * opening a passive data connection
-   * @throws FtpExceptionUnknownForcedDataClose if there is a bad reply from the
-   * FTP server
-   * @throws FtpExceptionControlClosedByForcedDataClose some ftp servers will 
-   * close control channel if data channel socket is closed by our end before 
-   * all data has been read out
+   * @param path
+   * @param entries
+   * @param limit
+   * @param parser
+   * @throws IOException
+   * @throws FtpExceptionCanNotHaveDataConnection
+   * @throws FtpExceptionUnknownForcedDataClose
+   * @throws FtpExceptionControlClosedByForcedDataClose
    */
   public void retrieveList(String path, List<FTPFile> entries, int limit,
       FTPFileEntryParser parser) throws IOException,
@@ -342,7 +331,7 @@ public class Client extends FTP {
           + ((path == null) ? "" : path));
 
     BufferedReader reader = new BufferedReader(new InputStreamReader(
-        socket.getInputStream()));
+        socket.getInputStream(), StandardCharsets.UTF_8));
 
     // force-close data channel socket, when download limit is reached
     // boolean mandatory_close = false;
@@ -395,21 +384,15 @@ public class Client extends FTP {
   }
 
   /**
-   * retrieve file for path
+   * Retrieve a file for path
    * 
-   * @param path a path on the FTP server
-   * @param os an {@link OutputStream} to write data to
-   * @param limit optionally impose a download limit if this value 
-   * is &gt;= 0, otherwise no limit
-   * @throws IOException if there is a fatal I/O error, could be related to 
-   * opening a passive data connection or retrieving data from the specified path
-   * @throws FtpExceptionCanNotHaveDataConnection if an error occurs whilst 
-   * opening a passive data connection
-   * @throws FtpExceptionUnknownForcedDataClose if there is a bad reply from the
-   * FTP server
-   * @throws FtpExceptionControlClosedByForcedDataClose some ftp servers will 
-   * close control channel if data channel socket is closed by our end before 
-   * all data has been read out
+   * @param path
+   * @param os
+   * @param limit
+   * @throws IOException
+   * @throws FtpExceptionCanNotHaveDataConnection
+   * @throws FtpExceptionUnknownForcedDataClose
+   * @throws FtpExceptionControlClosedByForcedDataClose
    */
   public void retrieveFile(String path, OutputStream os, int limit)
       throws IOException, FtpExceptionCanNotHaveDataConnection,
@@ -479,12 +462,7 @@ public class Client extends FTP {
 
   }
 
-  /**
-   * reply check after closing data connection
-   * 
-   * @param reply
-   * @return
-   */
+  // reply check after closing data connection
   private boolean _notBadReply(int reply) {
 
     if (FTPReply.isPositiveCompletion(reply)) {
@@ -553,7 +531,11 @@ public class Client extends FTP {
    * 
    * @return The system type name obtained from the server. null if the
    *         information could not be obtained.
-   * @exception FtpExceptionBadSystResponse indicating bad reply of SYST command
+   * @exception FTPConnectionClosedException
+   *              If the FTP server prematurely closes the connection as a
+   *              result of the client being idle or some other reason causing
+   *              the server to send FTP reply code 421. This exception may be
+   *              caught either as an IOException or independently as itself.
    * @exception IOException
    *              If an I/O error occurs while either sending a command to the
    *              server or receiving a reply from the server.
@@ -592,4 +574,13 @@ public class Client extends FTP {
     return FTPReply.isPositiveCompletion(noop());
   }
 
+  // client.stat(path);
+  // client.sendCommand("STAT");
+  // client.sendCommand("STAT",path);
+  // client.sendCommand("MDTM",path);
+  // client.sendCommand("SIZE",path);
+  // client.sendCommand("HELP","SITE");
+  // client.sendCommand("SYST");
+  // client.setRestartOffset(120);
+
 }
