@@ -1,4 +1,4 @@
-/*
+/**
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
@@ -14,6 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+
 package org.apache.nutch.plugin;
 
 /**
@@ -29,7 +30,6 @@ public class HelloWorldExtension implements ITestExtension {
    * @see
    * org.apache.nutch.plugin.ITestExtension#testGetExtension(java.lang.String)
    */
-  @Override
   public String testGetExtension(String hello) {
     return hello + " World";
   }
